@@ -1,11 +1,12 @@
 package Term::ExtendedColor;
 use strict;
+use warnings;
 
 BEGIN {
   use Exporter;
   use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
 
-  $VERSION = '0.230';
+  $VERSION = '0.232';
   @ISA     = qw(Exporter);
 
   @EXPORT_OK = qw(
@@ -29,8 +30,11 @@ BEGIN {
   );
 }
 
-*uncolour    = *Term::ExtendedColor::uncolor;
-*get_colours = *Term::ExtendedColor::get_colors;
+{
+  no warnings;
+  *uncolour    = *Term::ExtendedColor::uncolor;
+  *get_colours = *Term::ExtendedColor::get_colors;
+}
 
 our $AUTORESET = 1;
 
